LicenseExpr

Enum LicenseExpr 

pub enum LicenseExpr {
    Name(String),
    WithException(String, String),
    And(Vec<LicenseExpr>),
    Or(Vec<LicenseExpr>),
}
A parsed license expression from a DEP-5 copyright file.

Variants



Name(String)

A single license name, e.g. MIT.



WithException(String, String)

A license with an exception, e.g. GPL-2+ with OpenSSL-exception.



And(Vec<LicenseExpr>)

All of these licenses apply simultaneously.



Or(Vec<LicenseExpr>)

Any one of these licenses may be chosen.

Implementations

Source

impl LicenseExpr

pub fn parse(input: &str) -> Self

Parse a license expression string.

Examples
use debian_copyright::LicenseExpr;

let expr = LicenseExpr::parse("GPL-2+ or MIT");
assert_eq!(expr, LicenseExpr::Or(vec![
    LicenseExpr::Name("GPL-2+".to_string()),
    LicenseExpr::Name("MIT".to_string()),
]));

let expr = LicenseExpr::parse("GPL-2+ with OpenSSL-exception");
assert_eq!(expr, LicenseExpr::WithException(
    "GPL-2+".to_string(),
    "OpenSSL-exception".to_string(),
));
pub fn license_names(&self) -> Vec<&str>

Returns the individual license names contained in this expression.

For WithException variants, only the license name is returned, not the exception name.