FilesParagraph

Struct FilesParagraph 

pub struct FilesParagraph(/* private fields */);
A files paragraph

Implementations

Source

impl FilesParagraph

pub fn as_deb822(&self) -> &Paragraph

Return the underlying Deb822 paragraph

pub fn files(&self) -> Vec<String>

List of file patterns in the paragraph

pub fn set_files(&mut self, files: &[&str])

Set the file patterns in the paragraph

pub fn add_file(&mut self, pattern: &str)

Add a file pattern to the paragraph

If the pattern already exists, it will not be added again.

pub fn remove_file(&mut self, pattern: &str) -> bool

Remove a file pattern from the paragraph

Returns true if the pattern was found and removed, false otherwise.

pub fn matches(&self, filename: &Path) -> bool

Check whether the paragraph matches the given filename

pub fn copyright(&self) -> Vec<String>

Copyright holders in the paragraph

Set the copyright

pub fn comment(&self) -> Option<String>

Comment associated with the files paragraph

pub fn set_comment(&mut self, comment: &str)

Set the comment associated with the files paragraph

pub fn license(&self) -> Option<License>

License in the paragraph

pub fn set_license(&mut self, license: &License)

Set the license associated with the files paragraph