Header

Struct Header 

pub struct Header(/* private fields */);
A header paragraph

Implementations

Source

impl Header

pub fn format_string(&self) -> Option<String>

Returns the format string for this file.

pub fn as_deb822(&self) -> &Paragraph

Return the underlying Deb822 paragraph

pub fn as_mut_deb822(&mut self) -> &mut Paragraph

👎Deprecated: Use as_deb822 instead

Return the underlying Deb822 paragraph, mutably

pub fn upstream_name(&self) -> Option<String>

Upstream name

pub fn set_upstream_name(&mut self, name: &str)

Set the upstream name

pub fn upstream_contact(&self) -> Option<String>

Upstream contact

pub fn set_upstream_contact(&mut self, contact: &str)

Set the upstream contact

pub fn source(&self) -> Option<String>

pub fn set_source(&mut self, source: &str)

Set the source

pub fn files_excluded(&self) -> Option<Vec<String>>

List of files excluded from the copyright information, as well as the source package

pub fn set_files_excluded(&mut self, files: &[&str])

Set excluded files

pub fn fix(&mut self)

Fix the the header paragraph

Currently this just renames Format-Specification to Format and replaces older format strings with the current format string.